==> nextcloud-app-news-1%3A25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lv.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pieprasījums neizdevās, nav pieejams tīkla pieslēgums!",
    "Request unauthorized. Are you logged in?" : "Pieprasījums nav pilnvarots. Vai esot pieteicies?",
    "Token expired or app not enabled! Reload the page!" : "Pilnvara beigusies vai lietotne nav iespējota. Pārlādējiet lapu!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Iekšēja servera kļūda! Lūdzu pārbaudiet data/nextcloud.log papildus informācijai!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Pieprasījums neizdevās, Nextcloud pašlaik darbojas uzturēšanas režīmā!",
    "Unread articles" : "Nelasītie raksti",
    "Shared with me" : "Koplietots ar mani",
    "Download" : "Lejupielādēt",
    "Close" : "Aizvērt",
    "Web address" : "Tīmekļa adrese",
    "No folder" : "Nav mapes",
    "Folder name" : "Mapes nosaukums",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Feed exists already!" : "Plūsma jau pastāv.",
    "New folder" : "Jauna mape",
    "Folder exists already!" : "Mape jau pastāv.",
    "Credentials" : "Akreditācijas dati",
    "Subscribe" : "Abonēt",
    "Maximum redirects" : "Lielākais pieļaujamais pārvirzījumu skaits",
    "Use system cron for updates" : "Izmantot sistēmas cron atjauninājumiem",
    "Move" : "Pārvietot",
    "Share" : "Koplietot",
    "All articles" : "Visi raksti",
    "Starred" : "Svarīgs",
    "Settings" : "Iestatījumi",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Show all articles" : "Rādīt visus rakstus",
    "Rename" : "Pārsaukt",
    "Delete" : "Dzēst",
    "Newest first" : "Jaunākie pirms",
    "Oldest first" : "Vecākie pirms",
    "by" : "līdz",
    "from" : "no",
    "Play audio" : "Atskaņot audio",
    "Download audio" : "Lejupielādēt audio",
    "Download video" : "Lejupielādēt video",
    "Open website" : "Atvērt vietni",
    "{num} days ago" : "Pirms {num} dienām",
    "Title" : "Virsraksts",
    "Not available" : "Nav pieejams",
    "Keyboard shortcut" : "Tastatūras saīsne",
    "Action" : "Darbība",
    "right" : "pa labi",
    "left" : "pa kreisi",
    "Refresh" : "Atsvaidzināt",
    "Load previous folder" : "Ielādēt iepriekšējo mapi",
    "Load next folder" : "Ielādēt nākamo mapi",
    "Description" : "Apraksts",
    "Folder" : "Mape",
    "Go back" : "Atpakaļ",
    "New Folder" : "Jauna mape",
    "Create" : "Izveidot",
    "Update failed more than 50 times" : "Atjaunināšana neizdevās vairāk nekā 50 reizes",
    "Menu" : "Izvēlne",
    "Dismiss" : "Atmest",
    "Collapse" : "Sakļaut",
    "Deleted folder" : "Dzēstās mapes",
    "Compact view" : "Kompakts skats",
    "Subscriptions (OPML)" : "Abonementi (OPML)",
    "Import" : "Importēt",
    "Export" : "Eksportēt",
    "Error when importing: file does not contain valid JSON" : "Kļūda, importējot: datne nesatur derīgus JSON",
    "Help" : "Palīdzība",
    "Documentation" : "Dokumentācija",
    "Report a bug" : "Ziņot par kļūdu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-news-1%3A26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lv.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Nelasītie raksti",
    "Shared with me" : "Koplietots ar mani",
    "Download" : "Lejupielādēt",
    "Close" : "Aizvērt",
    "Web address" : "Tīmekļa adrese",
    "No folder" : "Nav mapes",
    "Folder name" : "Mapes nosaukums",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Feed exists already!" : "Plūsma jau pastāv.",
    "New folder" : "Jauna mape",
    "Folder exists already!" : "Mape jau pastāv.",
    "Credentials" : "Akreditācijas dati",
    "Subscribe" : "Abonēt",
    "Maximum redirects" : "Lielākais pieļaujamais pārvirzījumu skaits",
    "Use system cron for updates" : "Izmantot sistēmas cron atjauninājumiem",
    "Move" : "Pārvietot",
    "Share" : "Koplietot",
    "Rename Folder" : "Pārdēvēt mapi",
    "All articles" : "Visi raksti",
    "Starred" : "Svarīgs",
    "Explore" : "Izpētīt",
    "Settings" : "Iestatījumi",
    "Documentation" : "Dokumentācija",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Show all articles" : "Rādīt visus rakstus",
    "Rename" : "Pārdēvēt",
    "Delete" : "Izdzēst",
    "Rename Feed" : "Pārdēvēt barotni",
    "Open Feed URL" : "Atvērt barotnes URL",
    "Newest first" : "Jaunākie pirms",
    "Oldest first" : "Vecākie pirms",
    "Previous" : "Iepriekšējā",
    "by" : "līdz",
    "Play audio" : "Atskaņot audio",
    "Download audio" : "Lejupielādēt audio",
    "Download video" : "Lejupielādēt video",
    "Open website" : "Atvērt tīmekļvietni",
    "Not available" : "Nav pieejams",
    "Title" : "Virsraksts",
    "Keyboard shortcut" : "Tastatūras saīsne",
    "Action" : "Darbība",
    "right" : "pa labi",
    "left" : "pa kreisi",
    "Open article in new tab" : "Atvērt rakstu jaunā cilnē",
    "Refresh" : "Atsvaidzināt",
    "Load previous folder" : "Ielādēt iepriekšējo mapi",
    "Load next folder" : "Ielādēt nākamo mapi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
